# URL field

The url field mirrors the [basic field](./basic_field.md) for functionality. The only difference is that
it validates the user has entered a URL.

See the [basic field](./basic_field.md) documentation for configuration options.
